# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/trading/limit_order/v1/service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/trading/limit_order/v1/service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from meshtrade.option.method_options.v1 import method_options_pb2 as meshtrade_dot_option_dot_method__options_dot_v1_dot_method__options__pb2
from meshtrade.trading.limit_order.v1 import limit_order_pb2 as meshtrade_dot_trading_dot_limit__order_dot_v1_dot_limit__order__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.meshtrade/trading/limit_order/v1/service.proto\x12 meshtrade.trading.limit_order.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x37meshtrade/option/method_options/v1/method_options.proto\x1a\x32meshtrade/trading/limit_order/v1/limit_order.proto\"p\n\x17\x43reateLimitOrderRequest\x12U\n\x0blimit_order\x18\x01 \x01(\x0b\x32,.meshtrade.trading.limit_order.v1.LimitOrderB\x06\xbaH\x03\xc8\x01\x01R\nlimitOrder\"q\n\x17\x43\x61ncelLimitOrderRequest\x12V\n\x04name\x18\x01 \x01(\tBB\xbaH?r:25^limit_orders/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\x98\x01\'\xc8\x01\x01R\x04name\"\x98\x01\n\x14GetLimitOrderRequest\x12V\n\x04name\x18\x01 \x01(\tBB\xbaH?r:25^limit_orders/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\x98\x01\'\xc8\x01\x01R\x04name\x12(\n\x10live_ledger_data\x18\x02 \x01(\x08R\x0eliveLedgerData\"\x8a\x01\n\'GetLimitOrderByExternalReferenceRequest\x12\x35\n\x12\x65xternal_reference\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x11\x65xternalReference\x12(\n\x10live_ledger_data\x18\x02 \x01(\x08R\x0eliveLedgerData\"B\n\x16ListLimitOrdersRequest\x12(\n\x10live_ledger_data\x18\x01 \x01(\x08R\x0eliveLedgerData\"j\n\x17ListLimitOrdersResponse\x12O\n\x0climit_orders\x18\x01 \x03(\x0b\x32,.meshtrade.trading.limit_order.v1.LimitOrderR\x0blimitOrders\"\xf9\x01\n\x18SearchLimitOrdersRequest\x12\x14\n\x05token\x18\x01 \x01(\tR\x05token\x12R\n\x07\x61\x63\x63ount\x18\x02 \x01(\tB8\xbaH5r321^accounts/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$R\x07\x61\x63\x63ount\x12I\n\x06states\x18\x03 \x03(\x0e\x32\x31.meshtrade.trading.limit_order.v1.LimitOrderStateR\x06states\x12(\n\x10live_ledger_data\x18\x04 \x01(\x08R\x0eliveLedgerData\"l\n\x19SearchLimitOrdersResponse\x12O\n\x0climit_orders\x18\x01 \x03(\x0b\x32,.meshtrade.trading.limit_order.v1.LimitOrderR\x0blimitOrders\"\xda\x01\n\x18MonitorLimitOrderRequest\x12U\n\x04name\x18\x01 \x01(\tB?\xbaH<r:25^limit_orders/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\x98\x01\'H\x00R\x04name\x12/\n\x12\x65xternal_reference\x18\x02 \x01(\tH\x00R\x11\x65xternalReference\x12(\n\x10live_ledger_data\x18\x03 \x01(\x08R\x0eliveLedgerDataB\x0c\n\nidentifier2\xf5\x08\n\x11LimitOrderService\x12\x91\x01\n\x10\x43reateLimitOrder\x12\x39.meshtrade.trading.limit_order.v1.CreateLimitOrderRequest\x1a,.meshtrade.trading.limit_order.v1.LimitOrder\"\x14\xb2\xb5\x18\x10\x08\x02\x10\x02\x1a\x08\xc0\x96\xb1\x02\xc2\x96\xb1\x02 \x01\x12\x8f\x01\n\x10\x43\x61ncelLimitOrder\x12\x39.meshtrade.trading.limit_order.v1.CancelLimitOrderRequest\x1a,.meshtrade.trading.limit_order.v1.LimitOrder\"\x12\xb2\xb5\x18\x0e\x08\x02\x10\x02\x1a\x08\xc0\x96\xb1\x02\xc2\x96\xb1\x02\x12\x91\x01\n\rGetLimitOrder\x12\x36.meshtrade.trading.limit_order.v1.GetLimitOrderRequest\x1a,.meshtrade.trading.limit_order.v1.LimitOrder\"\x1a\xb2\xb5\x18\x16\x08\x01\x10\x02\x1a\x10\xc0\x96\xb1\x02\xc1\x96\xb1\x02\xc2\x96\xb1\x02\xc3\x96\xb1\x02\x12\xb7\x01\n GetLimitOrderByExternalReference\x12I.meshtrade.trading.limit_order.v1.GetLimitOrderByExternalReferenceRequest\x1a,.meshtrade.trading.limit_order.v1.LimitOrder\"\x1a\xb2\xb5\x18\x16\x08\x01\x10\x02\x1a\x10\xc0\x96\xb1\x02\xc1\x96\xb1\x02\xc2\x96\xb1\x02\xc3\x96\xb1\x02\x12\xa2\x01\n\x0fListLimitOrders\x12\x38.meshtrade.trading.limit_order.v1.ListLimitOrdersRequest\x1a\x39.meshtrade.trading.limit_order.v1.ListLimitOrdersResponse\"\x1a\xb2\xb5\x18\x16\x08\x01\x10\x02\x1a\x10\xc0\x96\xb1\x02\xc1\x96\xb1\x02\xc2\x96\xb1\x02\xc3\x96\xb1\x02\x12\xa8\x01\n\x11SearchLimitOrders\x12:.meshtrade.trading.limit_order.v1.SearchLimitOrdersRequest\x1a;.meshtrade.trading.limit_order.v1.SearchLimitOrdersResponse\"\x1a\xb2\xb5\x18\x16\x08\x01\x10\x02\x1a\x10\xc0\x96\xb1\x02\xc1\x96\xb1\x02\xc2\x96\xb1\x02\xc3\x96\xb1\x02\x12\x9b\x01\n\x11MonitorLimitOrder\x12:.meshtrade.trading.limit_order.v1.MonitorLimitOrderRequest\x1a,.meshtrade.trading.limit_order.v1.LimitOrder\"\x1a\xb2\xb5\x18\x16\x08\x01\x10\x02\x1a\x10\xc0\x96\xb1\x02\xc1\x96\xb1\x02\xc2\x96\xb1\x02\xc3\x96\xb1\x02\x30\x01\x42l\n\'co.meshtrade.api.trading.limit_order.v1ZAgithub.com/meshtrade/api/go/trading/limit_order/v1;limit_order_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.trading.limit_order.v1.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\'co.meshtrade.api.trading.limit_order.v1ZAgithub.com/meshtrade/api/go/trading/limit_order/v1;limit_order_v1'
  _globals['_CREATELIMITORDERREQUEST'].fields_by_name['limit_order']._loaded_options = None
  _globals['_CREATELIMITORDERREQUEST'].fields_by_name['limit_order']._serialized_options = b'\272H\003\310\001\001'
  _globals['_CANCELLIMITORDERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CANCELLIMITORDERREQUEST'].fields_by_name['name']._serialized_options = b'\272H?r:25^limit_orders/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\230\001\'\310\001\001'
  _globals['_GETLIMITORDERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETLIMITORDERREQUEST'].fields_by_name['name']._serialized_options = b'\272H?r:25^limit_orders/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\230\001\'\310\001\001'
  _globals['_GETLIMITORDERBYEXTERNALREFERENCEREQUEST'].fields_by_name['external_reference']._loaded_options = None
  _globals['_GETLIMITORDERBYEXTERNALREFERENCEREQUEST'].fields_by_name['external_reference']._serialized_options = b'\272H\003\310\001\001'
  _globals['_SEARCHLIMITORDERSREQUEST'].fields_by_name['account']._loaded_options = None
  _globals['_SEARCHLIMITORDERSREQUEST'].fields_by_name['account']._serialized_options = b'\272H5r321^accounts/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$'
  _globals['_MONITORLIMITORDERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_MONITORLIMITORDERREQUEST'].fields_by_name['name']._serialized_options = b'\272H<r:25^limit_orders/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\230\001\''
  _globals['_LIMITORDERSERVICE'].methods_by_name['CreateLimitOrder']._loaded_options = None
  _globals['_LIMITORDERSERVICE'].methods_by_name['CreateLimitOrder']._serialized_options = b'\262\265\030\020\010\002\020\002\032\010\300\226\261\002\302\226\261\002 \001'
  _globals['_LIMITORDERSERVICE'].methods_by_name['CancelLimitOrder']._loaded_options = None
  _globals['_LIMITORDERSERVICE'].methods_by_name['CancelLimitOrder']._serialized_options = b'\262\265\030\016\010\002\020\002\032\010\300\226\261\002\302\226\261\002'
  _globals['_LIMITORDERSERVICE'].methods_by_name['GetLimitOrder']._loaded_options = None
  _globals['_LIMITORDERSERVICE'].methods_by_name['GetLimitOrder']._serialized_options = b'\262\265\030\026\010\001\020\002\032\020\300\226\261\002\301\226\261\002\302\226\261\002\303\226\261\002'
  _globals['_LIMITORDERSERVICE'].methods_by_name['GetLimitOrderByExternalReference']._loaded_options = None
  _globals['_LIMITORDERSERVICE'].methods_by_name['GetLimitOrderByExternalReference']._serialized_options = b'\262\265\030\026\010\001\020\002\032\020\300\226\261\002\301\226\261\002\302\226\261\002\303\226\261\002'
  _globals['_LIMITORDERSERVICE'].methods_by_name['ListLimitOrders']._loaded_options = None
  _globals['_LIMITORDERSERVICE'].methods_by_name['ListLimitOrders']._serialized_options = b'\262\265\030\026\010\001\020\002\032\020\300\226\261\002\301\226\261\002\302\226\261\002\303\226\261\002'
  _globals['_LIMITORDERSERVICE'].methods_by_name['SearchLimitOrders']._loaded_options = None
  _globals['_LIMITORDERSERVICE'].methods_by_name['SearchLimitOrders']._serialized_options = b'\262\265\030\026\010\001\020\002\032\020\300\226\261\002\301\226\261\002\302\226\261\002\303\226\261\002'
  _globals['_LIMITORDERSERVICE'].methods_by_name['MonitorLimitOrder']._loaded_options = None
  _globals['_LIMITORDERSERVICE'].methods_by_name['MonitorLimitOrder']._serialized_options = b'\262\265\030\026\010\001\020\002\032\020\300\226\261\002\301\226\261\002\302\226\261\002\303\226\261\002'
  _globals['_CREATELIMITORDERREQUEST']._serialized_start=222
  _globals['_CREATELIMITORDERREQUEST']._serialized_end=334
  _globals['_CANCELLIMITORDERREQUEST']._serialized_start=336
  _globals['_CANCELLIMITORDERREQUEST']._serialized_end=449
  _globals['_GETLIMITORDERREQUEST']._serialized_start=452
  _globals['_GETLIMITORDERREQUEST']._serialized_end=604
  _globals['_GETLIMITORDERBYEXTERNALREFERENCEREQUEST']._serialized_start=607
  _globals['_GETLIMITORDERBYEXTERNALREFERENCEREQUEST']._serialized_end=745
  _globals['_LISTLIMITORDERSREQUEST']._serialized_start=747
  _globals['_LISTLIMITORDERSREQUEST']._serialized_end=813
  _globals['_LISTLIMITORDERSRESPONSE']._serialized_start=815
  _globals['_LISTLIMITORDERSRESPONSE']._serialized_end=921
  _globals['_SEARCHLIMITORDERSREQUEST']._serialized_start=924
  _globals['_SEARCHLIMITORDERSREQUEST']._serialized_end=1173
  _globals['_SEARCHLIMITORDERSRESPONSE']._serialized_start=1175
  _globals['_SEARCHLIMITORDERSRESPONSE']._serialized_end=1283
  _globals['_MONITORLIMITORDERREQUEST']._serialized_start=1286
  _globals['_MONITORLIMITORDERREQUEST']._serialized_end=1504
  _globals['_LIMITORDERSERVICE']._serialized_start=1507
  _globals['_LIMITORDERSERVICE']._serialized_end=2648
# @@protoc_insertion_point(module_scope)
