from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class InstrumentType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    INSTRUMENT_TYPE_UNSPECIFIED: _ClassVar[InstrumentType]
    INSTRUMENT_TYPE_OTHER: _ClassVar[InstrumentType]
    INSTRUMENT_TYPE_SHARE: _ClassVar[InstrumentType]
    INSTRUMENT_TYPE_PREFERENCE_SHARE: _ClassVar[InstrumentType]
    INSTRUMENT_TYPE_BOND: _ClassVar[InstrumentType]
    INSTRUMENT_TYPE_ETF: _ClassVar[InstrumentType]
    INSTRUMENT_TYPE_ETN: _ClassVar[InstrumentType]
    INSTRUMENT_TYPE_AMC: _ClassVar[InstrumentType]
    INSTRUMENT_TYPE_UNIT_TRUST: _ClassVar[InstrumentType]
    INSTRUMENT_TYPE_CRYPTO_CURRENCY: _ClassVar[InstrumentType]
    INSTRUMENT_TYPE_FIAT_CURRENCY: _ClassVar[InstrumentType]
    INSTRUMENT_TYPE_RIGHTS: _ClassVar[InstrumentType]
    INSTRUMENT_TYPE_GOLD: _ClassVar[InstrumentType]
    INSTRUMENT_TYPE_SILVER: _ClassVar[InstrumentType]
    INSTRUMENT_TYPE_PLATINUM: _ClassVar[InstrumentType]
    INSTRUMENT_TYPE_PALLADIUM: _ClassVar[InstrumentType]
    INSTRUMENT_TYPE_CRUDE_OIL: _ClassVar[InstrumentType]
    INSTRUMENT_TYPE_NATURAL_GAS: _ClassVar[InstrumentType]
    INSTRUMENT_TYPE_COPPER: _ClassVar[InstrumentType]
    INSTRUMENT_TYPE_CORN: _ClassVar[InstrumentType]
    INSTRUMENT_TYPE_WHEAT: _ClassVar[InstrumentType]
    INSTRUMENT_TYPE_SOYBEANS: _ClassVar[InstrumentType]
    INSTRUMENT_TYPE_FIAT_STABLECOIN: _ClassVar[InstrumentType]
    INSTRUMENT_TYPE_MONEY_MARKET_FUND: _ClassVar[InstrumentType]
    INSTRUMENT_TYPE_MONEY_MARKET_FUND_STABLECOIN: _ClassVar[InstrumentType]
    INSTRUMENT_TYPE_ENDOWMENT_WRAPPER: _ClassVar[InstrumentType]
    INSTRUMENT_TYPE_FUND: _ClassVar[InstrumentType]
    INSTRUMENT_TYPE_FUND_STABLECOIN: _ClassVar[InstrumentType]
INSTRUMENT_TYPE_UNSPECIFIED: InstrumentType
INSTRUMENT_TYPE_OTHER: InstrumentType
INSTRUMENT_TYPE_SHARE: InstrumentType
INSTRUMENT_TYPE_PREFERENCE_SHARE: InstrumentType
INSTRUMENT_TYPE_BOND: InstrumentType
INSTRUMENT_TYPE_ETF: InstrumentType
INSTRUMENT_TYPE_ETN: InstrumentType
INSTRUMENT_TYPE_AMC: InstrumentType
INSTRUMENT_TYPE_UNIT_TRUST: InstrumentType
INSTRUMENT_TYPE_CRYPTO_CURRENCY: InstrumentType
INSTRUMENT_TYPE_FIAT_CURRENCY: InstrumentType
INSTRUMENT_TYPE_RIGHTS: InstrumentType
INSTRUMENT_TYPE_GOLD: InstrumentType
INSTRUMENT_TYPE_SILVER: InstrumentType
INSTRUMENT_TYPE_PLATINUM: InstrumentType
INSTRUMENT_TYPE_PALLADIUM: InstrumentType
INSTRUMENT_TYPE_CRUDE_OIL: InstrumentType
INSTRUMENT_TYPE_NATURAL_GAS: InstrumentType
INSTRUMENT_TYPE_COPPER: InstrumentType
INSTRUMENT_TYPE_CORN: InstrumentType
INSTRUMENT_TYPE_WHEAT: InstrumentType
INSTRUMENT_TYPE_SOYBEANS: InstrumentType
INSTRUMENT_TYPE_FIAT_STABLECOIN: InstrumentType
INSTRUMENT_TYPE_MONEY_MARKET_FUND: InstrumentType
INSTRUMENT_TYPE_MONEY_MARKET_FUND_STABLECOIN: InstrumentType
INSTRUMENT_TYPE_ENDOWMENT_WRAPPER: InstrumentType
INSTRUMENT_TYPE_FUND: InstrumentType
INSTRUMENT_TYPE_FUND_STABLECOIN: InstrumentType
