# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/type/v1/contact_details.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/type/v1/contact_details.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'meshtrade/type/v1/contact_details.proto\x12\x11meshtrade.type.v1\"\xa4\x02\n\x0e\x43ontactDetails\x12#\n\remail_address\x18\x01 \x01(\tR\x0c\x65mailAddress\x12!\n\x0cphone_number\x18\x03 \x01(\tR\x0bphoneNumber\x12#\n\rmobile_number\x18\x05 \x01(\tR\x0cmobileNumber\x12\x18\n\x07website\x18\x06 \x01(\tR\x07website\x12\x1a\n\x08linkedin\x18\x07 \x01(\tR\x08linkedin\x12\x1a\n\x08\x66\x61\x63\x65\x62ook\x18\x08 \x01(\tR\x08\x66\x61\x63\x65\x62ook\x12\x1c\n\tinstagram\x18\t \x01(\tR\tinstagram\x12\x1b\n\tx_twitter\x18\n \x01(\tR\x08xTwitter\x12\x18\n\x07youtube\x18\x0b \x01(\tR\x07youtubeBG\n\x18\x63o.meshtrade.api.type.v1Z+github.com/meshtrade/api/go/type/v1;type_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.type.v1.contact_details_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\030co.meshtrade.api.type.v1Z+github.com/meshtrade/api/go/type/v1;type_v1'
  _globals['_CONTACTDETAILS']._serialized_start=63
  _globals['_CONTACTDETAILS']._serialized_end=355
# @@protoc_insertion_point(module_scope)
