# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/type/v1/ledger.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/type/v1/ledger.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1emeshtrade/type/v1/ledger.proto\x12\x11meshtrade.type.v1*\xc3\x01\n\x06Ledger\x12\x16\n\x12LEDGER_UNSPECIFIED\x10\x00\x12\x12\n\x0eLEDGER_STELLAR\x10\x03\x12\x12\n\x0eLEDGER_BITCOIN\x10\x05\x12\x13\n\x0fLEDGER_LITECOIN\x10\x07\x12\x13\n\x0fLEDGER_ETHEREUM\x10\t\x12\x0e\n\nLEDGER_XRP\x10\x0b\x12\x1b\n\x17LEDGER_SA_STOCK_BROKERS\x10\x0f\x12\x11\n\rLEDGER_SOLANA\x10\x10\x12\x0f\n\x0bLEDGER_NULL\x10\x11\x42G\n\x18\x63o.meshtrade.api.type.v1Z+github.com/meshtrade/api/go/type/v1;type_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.type.v1.ledger_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\030co.meshtrade.api.type.v1Z+github.com/meshtrade/api/go/type/v1;type_v1'
  _globals['_LEDGER']._serialized_start=54
  _globals['_LEDGER']._serialized_end=249
# @@protoc_insertion_point(module_scope)
