# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/iam/user_profile/v1/service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/iam/user_profile/v1/service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from meshtrade.iam.user_profile.v1 import user_profile_pb2 as meshtrade_dot_iam_dot_user__profile_dot_v1_dot_user__profile__pb2
from meshtrade.option.method_options.v1 import method_options_pb2 as meshtrade_dot_option_dot_method__options_dot_v1_dot_method__options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+meshtrade/iam/user_profile/v1/service.proto\x12\x1dmeshtrade.iam.user_profile.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x30meshtrade/iam/user_profile/v1/user_profile.proto\x1a\x37meshtrade/option/method_options/v1/method_options.proto\"\xfe\x02\n\x1bGetUserProfileByUserRequest\x12\xde\x02\n\x04user\x18\x01 \x01(\tB\xc9\x02\xbaH\xc5\x02r2\x10\x01\x32.^users/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\xba\x01V\n\ruser.required\x12\x35user is required and must be in format users/{ULIDv2}\x1a\x0esize(this) > 0\xba\x01\xb1\x01\n\x0buser.format\x12\x62name must be in format users/{ULIDv2} where ulidv2 is exactly 26 uppercase alphanumeric characters\x1a>this.matches(\'^users/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\')\xc8\x01\x01R\x04user\"q\n\x18UpdateUserProfileRequest\x12U\n\x0cuser_profile\x18\x01 \x01(\x0b\x32*.meshtrade.iam.user_profile.v1.UserProfileB\x06\xbaH\x03\xc8\x01\x01R\x0buserProfile\"\x98\x03\n\x15GetUserProfileRequest\x12\xfe\x02\n\x04name\x18\x01 \x01(\tB\xe9\x02\xbaH\xe5\x02r:\x10\x01\x32\x36^user_profiles/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\xba\x01^\n\rname.required\x12=name is required and must be in format user_profiles/{ULIDv2}\x1a\x0esize(this) > 0\xba\x01\xc1\x01\n\x0bname.format\x12jname must be in format user_profiles/{ULIDv2} where ulidv2 is exactly 26 uppercase alphanumeric characters\x1a\x46this.matches(\'^user_profiles/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\')\xc8\x01\x01R\x04name\"\x19\n\x17ListUserProfilesRequest\"k\n\x18ListUserProfilesResponse\x12O\n\ruser_profiles\x18\x01 \x03(\x0b\x32*.meshtrade.iam.user_profile.v1.UserProfileR\x0cuserProfiles2\xf3\x04\n\x12UserProfileService\x12\x8c\x01\n\x11UpdateUserProfile\x12\x37.meshtrade.iam.user_profile.v1.UpdateUserProfileRequest\x1a*.meshtrade.iam.user_profile.v1.UserProfile\"\x12\xb2\xb5\x18\x0e\x08\x02\x10\x02\x1a\x08\xc0\x8d\xb7\x01\xc8\x8d\xb7\x01\x12\x8e\x01\n\x0eGetUserProfile\x12\x34.meshtrade.iam.user_profile.v1.GetUserProfileRequest\x1a*.meshtrade.iam.user_profile.v1.UserProfile\"\x1a\xb2\xb5\x18\x16\x08\x01\x10\x02\x1a\x10\xc0\x8d\xb7\x01\xc1\x8d\xb7\x01\xc8\x8d\xb7\x01\xc9\x8d\xb7\x01\x12\x9a\x01\n\x14GetUserProfileByUser\x12:.meshtrade.iam.user_profile.v1.GetUserProfileByUserRequest\x1a*.meshtrade.iam.user_profile.v1.UserProfile\"\x1a\xb2\xb5\x18\x16\x08\x01\x10\x02\x1a\x10\xc0\x8d\xb7\x01\xc1\x8d\xb7\x01\xc8\x8d\xb7\x01\xc9\x8d\xb7\x01\x12\x9f\x01\n\x10ListUserProfiles\x12\x36.meshtrade.iam.user_profile.v1.ListUserProfilesRequest\x1a\x37.meshtrade.iam.user_profile.v1.ListUserProfilesResponse\"\x1a\xb2\xb5\x18\x16\x08\x01\x10\x02\x1a\x10\xc0\x8d\xb7\x01\xc1\x8d\xb7\x01\xc8\x8d\xb7\x01\xc9\x8d\xb7\x01\x42g\n$co.meshtrade.api.iam.user_profile.v1Z?github.com/meshtrade/api/go/iam/user_profile/v1;user_profile_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.iam.user_profile.v1.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n$co.meshtrade.api.iam.user_profile.v1Z?github.com/meshtrade/api/go/iam/user_profile/v1;user_profile_v1'
  _globals['_GETUSERPROFILEBYUSERREQUEST'].fields_by_name['user']._loaded_options = None
  _globals['_GETUSERPROFILEBYUSERREQUEST'].fields_by_name['user']._serialized_options = b'\272H\305\002r2\020\0012.^users/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\272\001V\n\ruser.required\0225user is required and must be in format users/{ULIDv2}\032\016size(this) > 0\272\001\261\001\n\013user.format\022bname must be in format users/{ULIDv2} where ulidv2 is exactly 26 uppercase alphanumeric characters\032>this.matches(\'^users/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\')\310\001\001'
  _globals['_UPDATEUSERPROFILEREQUEST'].fields_by_name['user_profile']._loaded_options = None
  _globals['_UPDATEUSERPROFILEREQUEST'].fields_by_name['user_profile']._serialized_options = b'\272H\003\310\001\001'
  _globals['_GETUSERPROFILEREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETUSERPROFILEREQUEST'].fields_by_name['name']._serialized_options = b'\272H\345\002r:\020\00126^user_profiles/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\272\001^\n\rname.required\022=name is required and must be in format user_profiles/{ULIDv2}\032\016size(this) > 0\272\001\301\001\n\013name.format\022jname must be in format user_profiles/{ULIDv2} where ulidv2 is exactly 26 uppercase alphanumeric characters\032Fthis.matches(\'^user_profiles/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\')\310\001\001'
  _globals['_USERPROFILESERVICE'].methods_by_name['UpdateUserProfile']._loaded_options = None
  _globals['_USERPROFILESERVICE'].methods_by_name['UpdateUserProfile']._serialized_options = b'\262\265\030\016\010\002\020\002\032\010\300\215\267\001\310\215\267\001'
  _globals['_USERPROFILESERVICE'].methods_by_name['GetUserProfile']._loaded_options = None
  _globals['_USERPROFILESERVICE'].methods_by_name['GetUserProfile']._serialized_options = b'\262\265\030\026\010\001\020\002\032\020\300\215\267\001\301\215\267\001\310\215\267\001\311\215\267\001'
  _globals['_USERPROFILESERVICE'].methods_by_name['GetUserProfileByUser']._loaded_options = None
  _globals['_USERPROFILESERVICE'].methods_by_name['GetUserProfileByUser']._serialized_options = b'\262\265\030\026\010\001\020\002\032\020\300\215\267\001\301\215\267\001\310\215\267\001\311\215\267\001'
  _globals['_USERPROFILESERVICE'].methods_by_name['ListUserProfiles']._loaded_options = None
  _globals['_USERPROFILESERVICE'].methods_by_name['ListUserProfiles']._serialized_options = b'\262\265\030\026\010\001\020\002\032\020\300\215\267\001\301\215\267\001\310\215\267\001\311\215\267\001'
  _globals['_GETUSERPROFILEBYUSERREQUEST']._serialized_start=215
  _globals['_GETUSERPROFILEBYUSERREQUEST']._serialized_end=597
  _globals['_UPDATEUSERPROFILEREQUEST']._serialized_start=599
  _globals['_UPDATEUSERPROFILEREQUEST']._serialized_end=712
  _globals['_GETUSERPROFILEREQUEST']._serialized_start=715
  _globals['_GETUSERPROFILEREQUEST']._serialized_end=1123
  _globals['_LISTUSERPROFILESREQUEST']._serialized_start=1125
  _globals['_LISTUSERPROFILESREQUEST']._serialized_end=1150
  _globals['_LISTUSERPROFILESRESPONSE']._serialized_start=1152
  _globals['_LISTUSERPROFILESRESPONSE']._serialized_end=1259
  _globals['_USERPROFILESERVICE']._serialized_start=1262
  _globals['_USERPROFILESERVICE']._serialized_end=1889
# @@protoc_insertion_point(module_scope)
