# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/compliance/client/v1/identification_document_type.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/compliance/client/v1/identification_document_type.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmeshtrade/compliance/client/v1/identification_document_type.proto\x12\x1emeshtrade.compliance.client.v1*\x88\x02\n\x1aIdentificationDocumentType\x12,\n(IDENTIFICATION_DOCUMENT_TYPE_UNSPECIFIED\x10\x00\x12)\n%IDENTIFICATION_DOCUMENT_TYPE_PASSPORT\x10\x01\x12,\n(IDENTIFICATION_DOCUMENT_TYPE_NATIONAL_ID\x10\x02\x12\x30\n,IDENTIFICATION_DOCUMENT_TYPE_DRIVERS_LICENSE\x10\x03\x12\x31\n-IDENTIFICATION_DOCUMENT_TYPE_RESIDENCE_PERMIT\x10\x04\x42\x63\n%co.meshtrade.api.compliance.client.v1Z:github.com/meshtrade/api/go/compliance/client/v1;client_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.compliance.client.v1.identification_document_type_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%co.meshtrade.api.compliance.client.v1Z:github.com/meshtrade/api/go/compliance/client/v1;client_v1'
  _globals['_IDENTIFICATIONDOCUMENTTYPE']._serialized_start=102
  _globals['_IDENTIFICATIONDOCUMENTTYPE']._serialized_end=366
# @@protoc_insertion_point(module_scope)
