# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/reporting/account_report/v1/fee_entry.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/reporting/account_report/v1/fee_entry.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from meshtrade.type.v1 import amount_pb2 as meshtrade_dot_type_dot_v1_dot_amount__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5meshtrade/reporting/account_report/v1/fee_entry.proto\x12%meshtrade.reporting.account_report.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1emeshtrade/type/v1/amount.proto\"\xc7\x02\n\x08\x46\x65\x65\x45ntry\x12\x45\n\x10transaction_date\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0ftransactionDate\x12%\n\x0etransaction_id\x18\x02 \x01(\tR\rtransactionId\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12\x31\n\x06\x61mount\x18\x04 \x01(\x0b\x32\x19.meshtrade.type.v1.AmountR\x06\x61mount\x12Q\n\x17reported_currency_value\x18\x05 \x01(\x0b\x32\x19.meshtrade.type.v1.AmountR\x15reportedCurrencyValue\x12%\n\x0etoken_currency\x18\x06 \x01(\tR\rtokenCurrencyBy\n,co.meshtrade.api.reporting.account_report.v1ZIgithub.com/meshtrade/api/go/reporting/account_report/v1;account_report_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.reporting.account_report.v1.fee_entry_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n,co.meshtrade.api.reporting.account_report.v1ZIgithub.com/meshtrade/api/go/reporting/account_report/v1;account_report_v1'
  _globals['_FEEENTRY']._serialized_start=162
  _globals['_FEEENTRY']._serialized_end=489
# @@protoc_insertion_point(module_scope)
