# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/market_data/price/v1/service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/market_data/price/v1/service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from meshtrade.market_data.price.v1 import price_pb2 as meshtrade_dot_market__data_dot_price_dot_v1_dot_price__pb2
from meshtrade.option.method_options.v1 import method_options_pb2 as meshtrade_dot_option_dot_method__options_dot_v1_dot_method__options__pb2
from meshtrade.type.v1 import token_pb2 as meshtrade_dot_type_dot_v1_dot_token__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,meshtrade/market_data/price/v1/service.proto\x12\x1emeshtrade.market_data.price.v1\x1a\x1b\x62uf/validate/validate.proto\x1a*meshtrade/market_data/price/v1/price.proto\x1a\x37meshtrade/option/method_options/v1/method_options.proto\x1a\x1dmeshtrade/type/v1/token.proto\"\xa7\x01\n!GetCurrentPriceByTokenPairRequest\x12?\n\nbase_token\x18\x01 \x01(\x0b\x32\x18.meshtrade.type.v1.TokenB\x06\xbaH\x03\xc8\x01\x01R\tbaseToken\x12\x41\n\x0bquote_token\x18\x02 \x01(\x0b\x32\x18.meshtrade.type.v1.TokenB\x06\xbaH\x03\xc8\x01\x01R\nquoteToken2\xb3\x01\n\x0cPriceService\x12\xa2\x01\n\x1aGetCurrentPriceByTokenPair\x12\x41.meshtrade.market_data.price.v1.GetCurrentPriceByTokenPairRequest\x1a%.meshtrade.market_data.price.v1.Price\"\x1a\xb2\xb5\x18\x16\x08\x01\x10\x02\x1a\x10\x80\xa4\xe8\x03\x81\xa4\xe8\x03\x82\xa4\xe8\x03\x83\xa4\xe8\x03\x42\x62\n%co.meshtrade.api.market_data.price.v1Z9github.com/meshtrade/api/go/market_data/price/v1;price_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.market_data.price.v1.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%co.meshtrade.api.market_data.price.v1Z9github.com/meshtrade/api/go/market_data/price/v1;price_v1'
  _globals['_GETCURRENTPRICEBYTOKENPAIRREQUEST'].fields_by_name['base_token']._loaded_options = None
  _globals['_GETCURRENTPRICEBYTOKENPAIRREQUEST'].fields_by_name['base_token']._serialized_options = b'\272H\003\310\001\001'
  _globals['_GETCURRENTPRICEBYTOKENPAIRREQUEST'].fields_by_name['quote_token']._loaded_options = None
  _globals['_GETCURRENTPRICEBYTOKENPAIRREQUEST'].fields_by_name['quote_token']._serialized_options = b'\272H\003\310\001\001'
  _globals['_PRICESERVICE'].methods_by_name['GetCurrentPriceByTokenPair']._loaded_options = None
  _globals['_PRICESERVICE'].methods_by_name['GetCurrentPriceByTokenPair']._serialized_options = b'\262\265\030\026\010\001\020\002\032\020\200\244\350\003\201\244\350\003\202\244\350\003\203\244\350\003'
  _globals['_GETCURRENTPRICEBYTOKENPAIRREQUEST']._serialized_start=242
  _globals['_GETCURRENTPRICEBYTOKENPAIRREQUEST']._serialized_end=409
  _globals['_PRICESERVICE']._serialized_start=412
  _globals['_PRICESERVICE']._serialized_end=591
# @@protoc_insertion_point(module_scope)
