# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/iam/user/v1/service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/iam/user/v1/service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from meshtrade.iam.user.v1 import user_pb2 as meshtrade_dot_iam_dot_user_dot_v1_dot_user__pb2
from meshtrade.option.method_options.v1 import method_options_pb2 as meshtrade_dot_option_dot_method__options_dot_v1_dot_method__options__pb2
from meshtrade.type.v1 import sorting_pb2 as meshtrade_dot_type_dot_v1_dot_sorting__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#meshtrade/iam/user/v1/service.proto\x12\x15meshtrade.iam.user.v1\x1a\x1b\x62uf/validate/validate.proto\x1a meshtrade/iam/user/v1/user.proto\x1a\x37meshtrade/option/method_options/v1/method_options.proto\x1a\x1fmeshtrade/type/v1/sorting.proto\"\xdb\x01\n\x18\x41ssignRolesToUserRequest\x12O\n\x04name\x18\x01 \x01(\tB;\xbaH8r32.^users/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\x98\x01 \xc8\x01\x01R\x04name\x12n\n\x05roles\x18\x02 \x03(\tBX\xbaHU\x92\x01O\"MrK\x10/\x18\x30\x32\x45^groups/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}/roles/[1-9][0-9]{6,7}$\xc8\x01\x01R\x05roles\"\xdd\x01\n\x1aRevokeRolesFromUserRequest\x12O\n\x04name\x18\x01 \x01(\tB;\xbaH8r32.^users/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\x98\x01 \xc8\x01\x01R\x04name\x12n\n\x05roles\x18\x02 \x03(\tBX\xbaHU\x92\x01O\"MrK\x10/\x18\x30\x32\x45^groups/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}/roles/[1-9][0-9]{6,7}$\xc8\x01\x01R\x05roles\"a\n\x0eGetUserRequest\x12O\n\x04name\x18\x01 \x01(\tB;\xbaH8r32.^users/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\x98\x01 \xc8\x01\x01R\x04name\"9\n\x15GetUserByEmailRequest\x12 \n\x05\x65mail\x18\x01 \x01(\tB\n\xbaH\x07r\x02`\x01\xc8\x01\x01R\x05\x65mail\"\x94\x02\n\x10ListUsersRequest\x12I\n\x07sorting\x18\x01 \x01(\x0b\x32/.meshtrade.iam.user.v1.ListUsersRequest.SortingR\x07sorting\x1a\xb4\x01\n\x07Sorting\x12r\n\x05\x66ield\x18\x01 \x01(\tB\\\xbaHYr\tR\x00R\x05\x65mail\xba\x01K\n\x0b\x66ield.valid\x12%field must be one of: email, or empty\x1a\x15this in [\'\', \'email\']R\x05\x66ield\x12\x35\n\x05order\x18\x02 \x01(\x0e\x32\x1f.meshtrade.type.v1.SortingOrderR\x05order\"F\n\x11ListUsersResponse\x12\x31\n\x05users\x18\x01 \x03(\x0b\x32\x1b.meshtrade.iam.user.v1.UserR\x05users\"3\n\x12SearchUsersRequest\x12\x1d\n\x05\x65mail\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x18\x64R\x05\x65mail\"H\n\x13SearchUsersResponse\x12\x31\n\x05users\x18\x01 \x03(\x0b\x32\x1b.meshtrade.iam.user.v1.UserR\x05users\"L\n\x11\x43reateUserRequest\x12\x37\n\x04user\x18\x01 \x01(\x0b\x32\x1b.meshtrade.iam.user.v1.UserB\x06\xbaH\x03\xc8\x01\x01R\x04user\"L\n\x11UpdateUserRequest\x12\x37\n\x04user\x18\x01 \x01(\x0b\x32\x1b.meshtrade.iam.user.v1.UserB\x06\xbaH\x03\xc8\x01\x01R\x04user2\xb4\x07\n\x0bUserService\x12u\n\x11\x41ssignRolesToUser\x12/.meshtrade.iam.user.v1.AssignRolesToUserRequest\x1a\x1b.meshtrade.iam.user.v1.User\"\x12\xb2\xb5\x18\x0e\x08\x02\x10\x02\x1a\x08\xc0\x8d\xb7\x01\xc6\x8d\xb7\x01\x12y\n\x13RevokeRolesFromUser\x12\x31.meshtrade.iam.user.v1.RevokeRolesFromUserRequest\x1a\x1b.meshtrade.iam.user.v1.User\"\x12\xb2\xb5\x18\x0e\x08\x02\x10\x02\x1a\x08\xc0\x8d\xb7\x01\xc6\x8d\xb7\x01\x12i\n\x07GetUser\x12%.meshtrade.iam.user.v1.GetUserRequest\x1a\x1b.meshtrade.iam.user.v1.User\"\x1a\xb2\xb5\x18\x16\x08\x01\x10\x02\x1a\x10\xc0\x8d\xb7\x01\xc1\x8d\xb7\x01\xc6\x8d\xb7\x01\xc7\x8d\xb7\x01\x12w\n\x0eGetUserByEmail\x12,.meshtrade.iam.user.v1.GetUserByEmailRequest\x1a\x1b.meshtrade.iam.user.v1.User\"\x1a\xb2\xb5\x18\x16\x08\x01\x10\x02\x1a\x10\xc0\x8d\xb7\x01\xc1\x8d\xb7\x01\xc6\x8d\xb7\x01\xc7\x8d\xb7\x01\x12z\n\tListUsers\x12\'.meshtrade.iam.user.v1.ListUsersRequest\x1a(.meshtrade.iam.user.v1.ListUsersResponse\"\x1a\xb2\xb5\x18\x16\x08\x01\x10\x02\x1a\x10\xc0\x8d\xb7\x01\xc1\x8d\xb7\x01\xc6\x8d\xb7\x01\xc7\x8d\xb7\x01\x12\x80\x01\n\x0bSearchUsers\x12).meshtrade.iam.user.v1.SearchUsersRequest\x1a*.meshtrade.iam.user.v1.SearchUsersResponse\"\x1a\xb2\xb5\x18\x16\x08\x01\x10\x02\x1a\x10\xc0\x8d\xb7\x01\xc1\x8d\xb7\x01\xc6\x8d\xb7\x01\xc7\x8d\xb7\x01\x12g\n\nCreateUser\x12(.meshtrade.iam.user.v1.CreateUserRequest\x1a\x1b.meshtrade.iam.user.v1.User\"\x12\xb2\xb5\x18\x0e\x08\x02\x10\x02\x1a\x08\xc0\x8d\xb7\x01\xc6\x8d\xb7\x01\x12g\n\nUpdateUser\x12(.meshtrade.iam.user.v1.UpdateUserRequest\x1a\x1b.meshtrade.iam.user.v1.User\"\x12\xb2\xb5\x18\x0e\x08\x02\x10\x02\x1a\x08\xc0\x8d\xb7\x01\xc6\x8d\xb7\x01\x42O\n\x1c\x63o.meshtrade.api.iam.user.v1Z/github.com/meshtrade/api/go/iam/user/v1;user_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.iam.user.v1.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034co.meshtrade.api.iam.user.v1Z/github.com/meshtrade/api/go/iam/user/v1;user_v1'
  _globals['_ASSIGNROLESTOUSERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_ASSIGNROLESTOUSERREQUEST'].fields_by_name['name']._serialized_options = b'\272H8r32.^users/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\230\001 \310\001\001'
  _globals['_ASSIGNROLESTOUSERREQUEST'].fields_by_name['roles']._loaded_options = None
  _globals['_ASSIGNROLESTOUSERREQUEST'].fields_by_name['roles']._serialized_options = b'\272HU\222\001O\"MrK\020/\03002E^groups/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}/roles/[1-9][0-9]{6,7}$\310\001\001'
  _globals['_REVOKEROLESFROMUSERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_REVOKEROLESFROMUSERREQUEST'].fields_by_name['name']._serialized_options = b'\272H8r32.^users/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\230\001 \310\001\001'
  _globals['_REVOKEROLESFROMUSERREQUEST'].fields_by_name['roles']._loaded_options = None
  _globals['_REVOKEROLESFROMUSERREQUEST'].fields_by_name['roles']._serialized_options = b'\272HU\222\001O\"MrK\020/\03002E^groups/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}/roles/[1-9][0-9]{6,7}$\310\001\001'
  _globals['_GETUSERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETUSERREQUEST'].fields_by_name['name']._serialized_options = b'\272H8r32.^users/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\230\001 \310\001\001'
  _globals['_GETUSERBYEMAILREQUEST'].fields_by_name['email']._loaded_options = None
  _globals['_GETUSERBYEMAILREQUEST'].fields_by_name['email']._serialized_options = b'\272H\007r\002`\001\310\001\001'
  _globals['_LISTUSERSREQUEST_SORTING'].fields_by_name['field']._loaded_options = None
  _globals['_LISTUSERSREQUEST_SORTING'].fields_by_name['field']._serialized_options = b'\272HYr\tR\000R\005email\272\001K\n\013field.valid\022%field must be one of: email, or empty\032\025this in [\'\', \'email\']'
  _globals['_SEARCHUSERSREQUEST'].fields_by_name['email']._loaded_options = None
  _globals['_SEARCHUSERSREQUEST'].fields_by_name['email']._serialized_options = b'\272H\004r\002\030d'
  _globals['_CREATEUSERREQUEST'].fields_by_name['user']._loaded_options = None
  _globals['_CREATEUSERREQUEST'].fields_by_name['user']._serialized_options = b'\272H\003\310\001\001'
  _globals['_UPDATEUSERREQUEST'].fields_by_name['user']._loaded_options = None
  _globals['_UPDATEUSERREQUEST'].fields_by_name['user']._serialized_options = b'\272H\003\310\001\001'
  _globals['_USERSERVICE'].methods_by_name['AssignRolesToUser']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['AssignRolesToUser']._serialized_options = b'\262\265\030\016\010\002\020\002\032\010\300\215\267\001\306\215\267\001'
  _globals['_USERSERVICE'].methods_by_name['RevokeRolesFromUser']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['RevokeRolesFromUser']._serialized_options = b'\262\265\030\016\010\002\020\002\032\010\300\215\267\001\306\215\267\001'
  _globals['_USERSERVICE'].methods_by_name['GetUser']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['GetUser']._serialized_options = b'\262\265\030\026\010\001\020\002\032\020\300\215\267\001\301\215\267\001\306\215\267\001\307\215\267\001'
  _globals['_USERSERVICE'].methods_by_name['GetUserByEmail']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['GetUserByEmail']._serialized_options = b'\262\265\030\026\010\001\020\002\032\020\300\215\267\001\301\215\267\001\306\215\267\001\307\215\267\001'
  _globals['_USERSERVICE'].methods_by_name['ListUsers']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['ListUsers']._serialized_options = b'\262\265\030\026\010\001\020\002\032\020\300\215\267\001\301\215\267\001\306\215\267\001\307\215\267\001'
  _globals['_USERSERVICE'].methods_by_name['SearchUsers']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['SearchUsers']._serialized_options = b'\262\265\030\026\010\001\020\002\032\020\300\215\267\001\301\215\267\001\306\215\267\001\307\215\267\001'
  _globals['_USERSERVICE'].methods_by_name['CreateUser']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['CreateUser']._serialized_options = b'\262\265\030\016\010\002\020\002\032\010\300\215\267\001\306\215\267\001'
  _globals['_USERSERVICE'].methods_by_name['UpdateUser']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['UpdateUser']._serialized_options = b'\262\265\030\016\010\002\020\002\032\010\300\215\267\001\306\215\267\001'
  _globals['_ASSIGNROLESTOUSERREQUEST']._serialized_start=216
  _globals['_ASSIGNROLESTOUSERREQUEST']._serialized_end=435
  _globals['_REVOKEROLESFROMUSERREQUEST']._serialized_start=438
  _globals['_REVOKEROLESFROMUSERREQUEST']._serialized_end=659
  _globals['_GETUSERREQUEST']._serialized_start=661
  _globals['_GETUSERREQUEST']._serialized_end=758
  _globals['_GETUSERBYEMAILREQUEST']._serialized_start=760
  _globals['_GETUSERBYEMAILREQUEST']._serialized_end=817
  _globals['_LISTUSERSREQUEST']._serialized_start=820
  _globals['_LISTUSERSREQUEST']._serialized_end=1096
  _globals['_LISTUSERSREQUEST_SORTING']._serialized_start=916
  _globals['_LISTUSERSREQUEST_SORTING']._serialized_end=1096
  _globals['_LISTUSERSRESPONSE']._serialized_start=1098
  _globals['_LISTUSERSRESPONSE']._serialized_end=1168
  _globals['_SEARCHUSERSREQUEST']._serialized_start=1170
  _globals['_SEARCHUSERSREQUEST']._serialized_end=1221
  _globals['_SEARCHUSERSRESPONSE']._serialized_start=1223
  _globals['_SEARCHUSERSRESPONSE']._serialized_end=1295
  _globals['_CREATEUSERREQUEST']._serialized_start=1297
  _globals['_CREATEUSERREQUEST']._serialized_end=1373
  _globals['_UPDATEUSERREQUEST']._serialized_start=1375
  _globals['_UPDATEUSERREQUEST']._serialized_end=1451
  _globals['_USERSERVICE']._serialized_start=1454
  _globals['_USERSERVICE']._serialized_end=2402
# @@protoc_insertion_point(module_scope)
