from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class SourceOfIncomeAndWealth(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    SOURCE_OF_INCOME_AND_WEALTH_UNSPECIFIED: _ClassVar[SourceOfIncomeAndWealth]
    SOURCE_OF_INCOME_AND_WEALTH_ALLOWANCES: _ClassVar[SourceOfIncomeAndWealth]
    SOURCE_OF_INCOME_AND_WEALTH_BURSARY: _ClassVar[SourceOfIncomeAndWealth]
    SOURCE_OF_INCOME_AND_WEALTH_COURT_ORDER: _ClassVar[SourceOfIncomeAndWealth]
    SOURCE_OF_INCOME_AND_WEALTH_LOAN_FINANCIAL_INSTITUTION: _ClassVar[SourceOfIncomeAndWealth]
    SOURCE_OF_INCOME_AND_WEALTH_LOAN_OTHER: _ClassVar[SourceOfIncomeAndWealth]
    SOURCE_OF_INCOME_AND_WEALTH_MAINTENANCE: _ClassVar[SourceOfIncomeAndWealth]
    SOURCE_OF_INCOME_AND_WEALTH_MATURING_INVESTMENTS: _ClassVar[SourceOfIncomeAndWealth]
    SOURCE_OF_INCOME_AND_WEALTH_PENSION: _ClassVar[SourceOfIncomeAndWealth]
    SOURCE_OF_INCOME_AND_WEALTH_RENTAL_INCOME: _ClassVar[SourceOfIncomeAndWealth]
    SOURCE_OF_INCOME_AND_WEALTH_COMPANY_PROFITS: _ClassVar[SourceOfIncomeAndWealth]
    SOURCE_OF_INCOME_AND_WEALTH_COMPANY_SALE: _ClassVar[SourceOfIncomeAndWealth]
    SOURCE_OF_INCOME_AND_WEALTH_DECEASED_ESTATE: _ClassVar[SourceOfIncomeAndWealth]
    SOURCE_OF_INCOME_AND_WEALTH_DIVORCE_SETTLEMENT: _ClassVar[SourceOfIncomeAndWealth]
    SOURCE_OF_INCOME_AND_WEALTH_GIFT_OR_DONATION: _ClassVar[SourceOfIncomeAndWealth]
    SOURCE_OF_INCOME_AND_WEALTH_INCOME_FROM_EMPLOYMENT: _ClassVar[SourceOfIncomeAndWealth]
    SOURCE_OF_INCOME_AND_WEALTH_INCOME_FROM_PREVIOUS_EMPLOYMENT: _ClassVar[SourceOfIncomeAndWealth]
    SOURCE_OF_INCOME_AND_WEALTH_INHERITANCE: _ClassVar[SourceOfIncomeAndWealth]
    SOURCE_OF_INCOME_AND_WEALTH_LOTTERY_WINNINGS_OR_GAMBLING: _ClassVar[SourceOfIncomeAndWealth]
    SOURCE_OF_INCOME_AND_WEALTH_SALE_OF_ASSET: _ClassVar[SourceOfIncomeAndWealth]
    SOURCE_OF_INCOME_AND_WEALTH_SALE_OF_SHARES: _ClassVar[SourceOfIncomeAndWealth]
    SOURCE_OF_INCOME_AND_WEALTH_SAVINGS_INVESTMENT_OR_DIVIDEND: _ClassVar[SourceOfIncomeAndWealth]
    SOURCE_OF_INCOME_AND_WEALTH_TRUST_DISTRIBUTIONS: _ClassVar[SourceOfIncomeAndWealth]
SOURCE_OF_INCOME_AND_WEALTH_UNSPECIFIED: SourceOfIncomeAndWealth
SOURCE_OF_INCOME_AND_WEALTH_ALLOWANCES: SourceOfIncomeAndWealth
SOURCE_OF_INCOME_AND_WEALTH_BURSARY: SourceOfIncomeAndWealth
SOURCE_OF_INCOME_AND_WEALTH_COURT_ORDER: SourceOfIncomeAndWealth
SOURCE_OF_INCOME_AND_WEALTH_LOAN_FINANCIAL_INSTITUTION: SourceOfIncomeAndWealth
SOURCE_OF_INCOME_AND_WEALTH_LOAN_OTHER: SourceOfIncomeAndWealth
SOURCE_OF_INCOME_AND_WEALTH_MAINTENANCE: SourceOfIncomeAndWealth
SOURCE_OF_INCOME_AND_WEALTH_MATURING_INVESTMENTS: SourceOfIncomeAndWealth
SOURCE_OF_INCOME_AND_WEALTH_PENSION: SourceOfIncomeAndWealth
SOURCE_OF_INCOME_AND_WEALTH_RENTAL_INCOME: SourceOfIncomeAndWealth
SOURCE_OF_INCOME_AND_WEALTH_COMPANY_PROFITS: SourceOfIncomeAndWealth
SOURCE_OF_INCOME_AND_WEALTH_COMPANY_SALE: SourceOfIncomeAndWealth
SOURCE_OF_INCOME_AND_WEALTH_DECEASED_ESTATE: SourceOfIncomeAndWealth
SOURCE_OF_INCOME_AND_WEALTH_DIVORCE_SETTLEMENT: SourceOfIncomeAndWealth
SOURCE_OF_INCOME_AND_WEALTH_GIFT_OR_DONATION: SourceOfIncomeAndWealth
SOURCE_OF_INCOME_AND_WEALTH_INCOME_FROM_EMPLOYMENT: SourceOfIncomeAndWealth
SOURCE_OF_INCOME_AND_WEALTH_INCOME_FROM_PREVIOUS_EMPLOYMENT: SourceOfIncomeAndWealth
SOURCE_OF_INCOME_AND_WEALTH_INHERITANCE: SourceOfIncomeAndWealth
SOURCE_OF_INCOME_AND_WEALTH_LOTTERY_WINNINGS_OR_GAMBLING: SourceOfIncomeAndWealth
SOURCE_OF_INCOME_AND_WEALTH_SALE_OF_ASSET: SourceOfIncomeAndWealth
SOURCE_OF_INCOME_AND_WEALTH_SALE_OF_SHARES: SourceOfIncomeAndWealth
SOURCE_OF_INCOME_AND_WEALTH_SAVINGS_INVESTMENT_OR_DIVIDEND: SourceOfIncomeAndWealth
SOURCE_OF_INCOME_AND_WEALTH_TRUST_DISTRIBUTIONS: SourceOfIncomeAndWealth
