# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/testing/ledger/token_tap/v1/option.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/testing/ledger/token_tap/v1/option.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2meshtrade/testing/ledger/token_tap/v1/option.proto\x12%meshtrade.testing.ledger.token_tap.v1\"\x97\x01\n\x10MintTokenOptions\x12m\n\x14stellar_mint_options\x18\x01 \x01(\x0b\x32\x39.meshtrade.testing.ledger.token_tap.v1.StellarMintOptionsH\x00R\x12stellarMintOptionsB\x14\n\x12mint_token_options\"h\n\x12StellarMintOptions\x12R\n\x07options\x18\x01 \x03(\x0b\x32\x38.meshtrade.testing.ledger.token_tap.v1.StellarMintOptionR\x07options\"\xae\x01\n\x11StellarMintOption\x12\x81\x01\n\x1cstellar_mint_token_with_memo\x18\x01 \x01(\x0b\x32?.meshtrade.testing.ledger.token_tap.v1.StellarMintTokenWithMemoH\x00R\x18stellarMintTokenWithMemoB\x15\n\x13stellar_mint_option\".\n\x18StellarMintTokenWithMemo\x12\x12\n\x04memo\x18\x01 \x01(\tR\x04memoBt\n,co.meshtrade.api.testing.ledger.token_tap.v1ZDgithub.com/meshtrade/api/go/testing/ledger/token_tap/v1;token_tap_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.testing.ledger.token_tap.v1.option_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n,co.meshtrade.api.testing.ledger.token_tap.v1ZDgithub.com/meshtrade/api/go/testing/ledger/token_tap/v1;token_tap_v1'
  _globals['_MINTTOKENOPTIONS']._serialized_start=94
  _globals['_MINTTOKENOPTIONS']._serialized_end=245
  _globals['_STELLARMINTOPTIONS']._serialized_start=247
  _globals['_STELLARMINTOPTIONS']._serialized_end=351
  _globals['_STELLARMINTOPTION']._serialized_start=354
  _globals['_STELLARMINTOPTION']._serialized_end=528
  _globals['_STELLARMINTTOKENWITHMEMO']._serialized_start=530
  _globals['_STELLARMINTTOKENWITHMEMO']._serialized_end=576
# @@protoc_insertion_point(module_scope)
